[llvm-branch-commits] [llvm-gcc-branch] r96400 - in /llvm-gcc-4.2/branches/Apple/Hermes/gcc: ada/sinfo.ads objc/objc-act.c

Bill Wendling isanbard at gmail.com
Tue Feb 16 13:56:01 PST 2010


Author: void
Date: Tue Feb 16 15:55:57 2010
New Revision: 96400

URL: http://llvm.org/viewvc/llvm-project?rev=96400&view=rev
Log:
$ svn merge -c 96398 https://llvm.org/svn/llvm-project/llvm-gcc-4.2/trunk
--- Merging r96398 into '.':
U    gcc/objc/objc-act.c
U    gcc/ada/sinfo.ads


Modified:
    llvm-gcc-4.2/branches/Apple/Hermes/gcc/ada/sinfo.ads
    llvm-gcc-4.2/branches/Apple/Hermes/gcc/objc/objc-act.c

Modified: llvm-gcc-4.2/branches/Apple/Hermes/gcc/ada/sinfo.ads
URL: http://llvm.org/viewvc/llvm-project/llvm-gcc-4.2/branches/Apple/Hermes/gcc/ada/sinfo.ads?rev=96400&r1=96399&r2=96400&view=diff

==============================================================================
--- llvm-gcc-4.2/branches/Apple/Hermes/gcc/ada/sinfo.ads (original)
+++ llvm-gcc-4.2/branches/Apple/Hermes/gcc/ada/sinfo.ads Tue Feb 16 15:55:57 2010
@@ -1149,7 +1149,7 @@
 
    --  Is_Protected_Subprogram_Body (Flag7-Sem)
    --    A flag set in a Subprogram_Body block to indicate that it is the
-   --    implemenation of a protected subprogram. Such a body needs cleanup
+   --    implementation of a protected subprogram. Such a body needs cleanup
    --    handler to make sure that the associated protected object is unlocked
    --    when the subprogram completes.
 

Modified: llvm-gcc-4.2/branches/Apple/Hermes/gcc/objc/objc-act.c
URL: http://llvm.org/viewvc/llvm-project/llvm-gcc-4.2/branches/Apple/Hermes/gcc/objc/objc-act.c?rev=96400&r1=96399&r2=96400&view=diff

==============================================================================
--- llvm-gcc-4.2/branches/Apple/Hermes/gcc/objc/objc-act.c (original)
+++ llvm-gcc-4.2/branches/Apple/Hermes/gcc/objc/objc-act.c Tue Feb 16 15:55:57 2010
@@ -1274,7 +1274,7 @@
     }
   if (objc_implementation_context)
     {
-      error ("property cannot be declared inside @implemenation context");
+      error ("property cannot be declared inside @implementation context");
       return;
     }
   else if (!objc_interface_context)
@@ -10241,7 +10241,7 @@
 }
 
 
 /* Build following types which represent each class implemenation.
 
   struct class_t {
     struct class_t *isa;
@@ -16809,7 +16809,7 @@
 /* APPLE LOCAL end radar 4966565 */
 
 /* Main routine to generate code/data for all the property information for 
-   current implemenation (class or category). CLASS is the interface where
+   current implementation (class or category). CLASS is the interface where
    ivars are declared in. CLASS_METHODS is where methods are found which
    could be a class or a category depending on wheter we are implementing
    property of a class or a category.  */
@@ -10241,7 +10241,7 @@
 
 
-/* Build following types which represent each class implemenation.
+/* Build following types which represent each class implementation.
 
   struct class_t {





More information about the llvm-branch-commits mailing list